# CohortFilter

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**dataset_id** | **str** |  | [optional] 
**enabled** | **bool** |  | [optional] 
**order** | **float** |  | 
**period_definition** | **str** |  | [optional] 
**period_preposition** | **str** |  | [optional] 
**start_date** | **datetime** |  | [optional] 
**end_date** | **datetime** |  | [optional] 
**cohort_filter_conditions** | [**list[CohortFilterCondition]**](CohortFilterCondition.md) |  | [optional] 
**type** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

